==> miniorange_saml-7.x-2.51.tar.gz: miniorange_saml/includes/miniorange_saml_support.php <==
<?php
/**
 * @file
 * Contains miniOrange Support class.
 */

/**
 * @file
 * This class represents support information for customer.
 */
class MiniorangeSamlSupport {
	public $email;
	public $phone;
	public $query;
	/**
     * Constructor.
     */
	public function __construct($email, $phone, $query) {
      $this->email = $email;
      $this->phone = $phone;
      $this->query = $query;
	}

	/**
	 * Send support query.
	 */
	public function sendSupportQuery() {

	  $proxy_host_name = variable_get('miniorange_saml_proxy_host','');
	  $port_number = variable_get('miniorange_saml_proxy_port','');
	  $username = variable_get('miniorange_saml_proxy_username');
	  $password = variable_get('miniorange_saml_proxy_password','');

      $this->query = '[Drupal-7 SAML SP Free]' . $this->query;
      $fields = array (
        'company' => $_SERVER ['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
        'subject' => "Drupal-7 SAML SP Free Query",
      );
      $field_string = json_encode ($fields);
      $url = MiniorangeSAMLConstants::BASE_URL . '/moas/rest/customer/contact-us';
      $ch = curl_init ( $url );
      curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
      curl_setopt($ch, CURLOPT_ENCODING, "");
      curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
      curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
      curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
      curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
      curl_setopt($ch, CURLOPT_HTTPHEADER, array (
        'Content-Type: application/json',
        'charset: UTF-8',
        'Authorization: Basic'
      ));
      curl_setopt($ch, CURLOPT_POST, TRUE);
      curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);

	  if(!empty($proxy_host_name)){
			curl_setopt($ch, CURLOPT_PROXY, $proxy_host_name);
			curl_setopt($ch, CURLOPT_PROXYPORT, $port_number);
			curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
			curl_setopt($ch, CURLOPT_PROXYUSERPWD, $username .':'. $password);
		}

      $content = curl_exec($ch);
	  if (curl_errno($ch)) {
        $error = array(
          '%method' => 'sendSupportQuery',
          '%file' => 'miniorange_saml_support.php',
          '%error' => curl_error($ch),
        );
        watchdog('miniorange_saml', 'cURL Error at %method of %file: %error', $error);
        return FALSE;
      }
      curl_close ($ch);
      return TRUE;
	}
}

==> miniorange_saml-7.x-2.52.tar.gz: miniorange_saml/includes/miniorange_saml_support.php <==
<?php
/**
 * @file
 * Contains miniOrange Support class.
 */

/**
 * @file
 * This class represents support information for customer.
 */
class MiniorangeSamlSupport {
	public $email;
	public $phone;
	public $query;
	/**
     * Constructor.
     */
	public function __construct($email, $phone, $query) {
      $this->email = $email;
      $this->phone = $phone;
      $this->query = $query;
	}

	/**
	 * Send support query.
	 */
	public function sendSupportQuery() {

	  $proxy_host_name = variable_get('miniorange_saml_proxy_host','');
	  $port_number = variable_get('miniorange_saml_proxy_port','');
	  $username = variable_get('miniorange_saml_proxy_username');
	  $password = variable_get('miniorange_saml_proxy_password','');

      $this->query = '[Drupal-7 SAML SP Free] :' . $this->query;
      $fields = array (
        'company' => $_SERVER ['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
        'subject' => "Drupal-7 SAML SP Free Query",
      );
      $field_string = json_encode ($fields);
      $url = MiniorangeSAMLConstants::BASE_URL . '/moas/rest/customer/contact-us';
      $ch = curl_init ( $url );
      curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
      curl_setopt($ch, CURLOPT_ENCODING, "");
      curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
      curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
      curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
      curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
      curl_setopt($ch, CURLOPT_HTTPHEADER, array (
        'Content-Type: application/json',
        'charset: UTF-8',
        'Authorization: Basic'
      ));
      curl_setopt($ch, CURLOPT_POST, TRUE);
      curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);

	  if(!empty($proxy_host_name)){
			curl_setopt($ch, CURLOPT_PROXY, $proxy_host_name);
			curl_setopt($ch, CURLOPT_PROXYPORT, $port_number);
			curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
			curl_setopt($ch, CURLOPT_PROXYUSERPWD, $username .':'. $password);
		}

      $content = curl_exec($ch);
	  if (curl_errno($ch)) {
        $error = array(
          '%method' => 'sendSupportQuery',
          '%file' => 'miniorange_saml_support.php',
          '%error' => curl_error($ch),
        );
        watchdog('miniorange_saml', 'cURL Error at %method of %file: %error', $error);
        return FALSE;
      }
      curl_close ($ch);
      return TRUE;
	}
}
